﻿using System;
using System.IO;

namespace FMx
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 1)
            {
                Console.WriteLine("Usage: fmx <save>");
                return;
            }

            Console.WriteLine("Factorio Map Fixer started!");
            
            var mainSave = new FileInfo(args[0]);
            if (!mainSave.Exists)
            {
                Console.WriteLine("Save file does not exist!");
                return;
            }
            
            var directory = mainSave.Directory;
            if (directory == null || !directory.Exists)
            {
                Console.WriteLine("Save directory does not exist!");
                return;
            }

            FileInfo latestSave = null;
            foreach (var file in directory.EnumerateFiles())
            {
                if (file.Name != mainSave.Name && (latestSave == null || file.LastWriteTimeUtc > latestSave.LastWriteTimeUtc))
                {
                    latestSave = file;
                }
            }

            if (latestSave != null && latestSave.LastWriteTimeUtc > mainSave.LastWriteTimeUtc)
            {
                Console.WriteLine($"{latestSave.Name} is newer than {mainSave.Name}!");

                var backupSaveName = mainSave.FullName + ".bak";
                if (File.Exists(backupSaveName))
                {
                    Console.WriteLine("Removing old backup..");
                    File.Delete(backupSaveName);
                }

                Console.WriteLine($"Moving {mainSave.Name} for backup..");
                File.Move(mainSave.FullName, backupSaveName);

                Console.WriteLine($"Moving {latestSave.Name} to {mainSave.Name}..");
                File.Move(latestSave.FullName, mainSave.FullName);

                Console.WriteLine("All done!");
            }
            else
            {
                Console.WriteLine("No newer save files could be found. Nothing to do! :)");
            }
        }
    }
}
